@@ -40,7 +40,7 @@
 #define NAUTILUS_FILE_TOP_LEFT_TEXT_MAXIMUM_BYTES               1024
 
 #define NAUTILUS_FILE_DEFAULT_ATTRIBUTES				\
-	"standard::*,access::*,mountable::*,time::*,unix::*,owner::*,selinux::*,thumbnail::*,id::filesystem,trash::orig-path"
+	"standard::*,access::*,mountable::*,time::*,unix::*,owner::*,selinux::*,thumbnail::*,id::filesystem,trash::orig-path,trash::deletion-date,metadata::*"
 
 /* These are in the typical sort order. Known things come first, then
  * things where we can't know, finally things where we don't yet know.
@@ -111,7 +111,7 @@ struct NautilusFileDetails
 
 	/* Info you might get from a link (.desktop, .directory or nautilus link) */
 	char *custom_icon;
-	GFile *activation_location;
+	char *activation_uri;
 
 	/* used during DND, for checking whether source and destination are on
 	 * the same file system.
@@ -142,6 +142,8 @@ struct NautilusFileDetails
 	GHashTable *extension_attributes;
 	GHashTable *pending_extension_attributes;
 
+	GHashTable *metadata;
+
 	/* Mount for mountpoint or the references GMount for a "mountable" */
 	GMount *mount;
 	
@@ -183,7 +185,7 @@ struct NautilusFileDetails
 	eel_boolean_bit got_link_info                 : 1;
 	eel_boolean_bit link_info_is_up_to_date       : 1;
 	eel_boolean_bit got_custom_display_name       : 1;
-	eel_boolean_bit got_custom_activation_location : 1;
+	eel_boolean_bit got_custom_activation_uri     : 1;
 
 	eel_boolean_bit thumbnail_is_up_to_date       : 1;
 	eel_boolean_bit thumbnail_wants_original      : 1;
@@ -214,10 +216,18 @@ struct NautilusFileDetails
 	eel_boolean_bit can_mount                     : 1;
 	eel_boolean_bit can_unmount                   : 1;
 	eel_boolean_bit can_eject                     : 1;
+	eel_boolean_bit can_start                     : 1;
+	eel_boolean_bit can_start_degraded            : 1;
+	eel_boolean_bit can_stop                      : 1;
+	eel_boolean_bit start_stop_type               : 3; /* GDriveStartStopType */
+	eel_boolean_bit can_poll_for_media            : 1;
+	eel_boolean_bit is_media_check_automatic      : 1;
 
 	eel_boolean_bit filesystem_readonly           : 1;
 	eel_boolean_bit filesystem_use_preview        : 2; /* GFilesystemPreviewType */
 	eel_boolean_bit filesystem_info_is_up_to_date : 1;
+
+	time_t trash_time; /* 0 is unknown */
 };
 
 typedef struct {
@@ -255,6 +265,8 @@ gboolean      nautilus_file_update_info                    (NautilusFile
 							    GFileInfo              *info);
 gboolean      nautilus_file_update_name                    (NautilusFile           *file,
 							    const char             *name);
+gboolean      nautilus_file_update_metadata_from_info      (NautilusFile           *file,
+							    GFileInfo              *info);
 
 gboolean      nautilus_file_update_name_and_directory      (NautilusFile           *file,
 							    const char             *name,
