@@ -32,11 +32,17 @@
 #include <gio/gio.h>
 #include <libnautilus-private/nautilus-file.h>
 
-#define FM_TYPE_TREE_MODEL	    (fm_tree_model_get_type ())
-#define FM_TREE_MODEL(obj)	    (GTK_CHECK_CAST ((obj), FM_TYPE_TREE_MODEL, FMTreeModel))
-#define FM_TREE_MODEL_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), FM_TYPE_TREE_MODEL, FMTreeModelClass))
-#define FM_IS_TREE_MODEL(obj)	    (GTK_CHECK_TYPE ((obj), FM_TYPE_TREE_MODEL))
-#define FM_IS_TREE_MODEL_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), FM_TYPE_TREE_MODEL))
+#define FM_TYPE_TREE_MODEL fm_tree_model_get_type()
+#define FM_TREE_MODEL(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST ((obj), FM_TYPE_TREE_MODEL, FMTreeModel))
+#define FM_TREE_MODEL_CLASS(klass) \
+  (G_TYPE_CHECK_CLASS_CAST ((klass), FM_TYPE_TREE_MODEL, FMTreeModelClass))
+#define FM_IS_TREE_MODEL(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FM_TYPE_TREE_MODEL))
+#define FM_IS_TREE_MODEL_CLASS(klass) \
+  (G_TYPE_CHECK_CLASS_TYPE ((klass), FM_TYPE_TREE_MODEL))
+#define FM_TREE_MODEL_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_CLASS ((obj), FM_TYPE_TREE_MODEL, FMTreeModelClass))
 
 enum {
 	FM_TREE_MODEL_DISPLAY_NAME_COLUMN,
@@ -44,7 +50,6 @@ enum {
 	FM_TREE_MODEL_OPEN_PIXBUF_COLUMN,
 	FM_TREE_MODEL_EMBLEM_PIXBUF_COLUMN,
 	FM_TREE_MODEL_FONT_STYLE_COLUMN,
-	FM_TREE_MODEL_FONT_WEIGHT_COLUMN,
 	FM_TREE_MODEL_NUM_COLUMNS
 };
 
@@ -90,5 +95,7 @@ gboolean           fm_tree_model_file_get_iter             (FMTreeModel *model,
 GMount *         fm_tree_model_get_mount_for_root_node_file        
                                                            (FMTreeModel  *model, 
                                                             NautilusFile *file);
+void             fm_tree_model_set_highlight_for_files    (FMTreeModel *model,
+                                                            GList *files);
 
 #endif /* FM_TREE_MODEL_H */
