@@ -29,6 +29,7 @@
 
 #include <gdk/gdk.h>
 #include <gio/gio.h>
+#include <unique/unique.h>
 #include <libegg/eggsmclient.h>
 #include <libnautilus-private/nautilus-undo-manager.h>
 
@@ -60,7 +61,7 @@ typedef struct NautilusShell NautilusShell;
 
 typedef struct {
 	GObject parent;
-	GApplication *unique_app;
+	UniqueApp *unique_app;
         EggSMClient *smclient;
 	NautilusUndoManager *undo_manager;
 	GVolumeMonitor *volume_monitor;
